@@ -18,9 +18,12 @@ import urllib
 import time
 from os import listdir
 from os.path import dirname, join
-import pandas from
+import pandas as pd
 
-from .configs import weekdays, conf, boostrap_ratio
+try:
+    from .configs import weekdays, conf, boostrap_ratio, web_port_default
+except:
+    from configs import weekdays, conf, boostrap_ratio, web_port_default
 
 
 def callfunc(my_file):
@@ -296,6 +299,13 @@ def get_results(date_col):
     return results
 
 
+def find_web_port():
+    web_port = web_port_default
+    while is_port_in_use(web_port):
+        web_port += 1
+    return web_port
+
+
 
 
 
